Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type ModuleInstance ¶ added in v1.1.0
type ModuleInstance struct {
// contains filtered or unexported fields
}
ModuleInstance represents an instance of the JS module.
func (*ModuleInstance) Exports ¶ added in v1.1.0
func (mi *ModuleInstance) Exports() modules.Exports
Exports implements the modules.Instance interface and returns the exported types for the JS module.
type RootModule ¶ added in v1.1.0
type RootModule struct{}
RootModule is the global module instance that will create module instances for each VU.
func New ¶ added in v1.1.0
func New() *RootModule
New returns a pointer to a new RootModule instance.
func (*RootModule) NewModuleInstance ¶ added in v1.1.0
func (*RootModule) NewModuleInstance(vu modules.VU) modules.Instance
NewModuleInstance implements the modules.Module interface returning a new instance for each VU.
Click to show internal directories.
Click to hide internal directories.